@@ -1,9 +1,9 @@
 structure(list(url = "https://api.open-meteo.com/v1/forecast?latitude=-12.46113&longitude=130.84184&current_weather=TRUE&timezone=auto&temperature_unit=asdfsfd&windspeed_unit=asdfsd", 
-    status_code = 400L, headers = structure(list(date = "Tue, 17 Oct 2023 10:19:25 GMT", 
+    status_code = 400L, headers = structure(list(date = "Wed, 25 Oct 2023 11:27:09 GMT", 
         `content-type` = "application/json; charset=utf-8", `content-length` = "102", 
         `content-encoding` = "deflate"), class = c("insensitive", 
     "list")), all_headers = list(list(status = 400L, version = "HTTP/2", 
-        headers = structure(list(date = "Tue, 17 Oct 2023 10:19:25 GMT", 
+        headers = structure(list(date = "Wed, 25 Oct 2023 11:27:09 GMT", 
             `content-type` = "application/json; charset=utf-8", 
             `content-length` = "102", `content-encoding` = "deflate"), class = c("insensitive", 
         "list")))), cookies = structure(list(domain = logical(0), 
@@ -11,7 +11,7 @@ structure(list(url = "https://api.open-meteo.com/v1/forecast?latitude=-12.46113&
         expiration = structure(numeric(0), class = c("POSIXct", 
         "POSIXt")), name = logical(0), value = logical(0)), row.names = integer(0), class = "data.frame"), 
     content = charToRaw("{\"error\":true,\"reason\":\"Cannot initialize TemperatureUnit from invalid String value asdfsfd for key temperature_unit\"}"), 
-    date = structure(1697537965, class = c("POSIXct", "POSIXt"
-    ), tzone = "GMT"), times = c(redirect = 0, namelookup = 3.9e-05, 
-    connect = 3.9e-05, pretransfer = 0.000192, starttransfer = 0.295334, 
-    total = 0.295457)), class = "response")
+    date = structure(1698233229, class = c("POSIXct", "POSIXt"
+    ), tzone = "GMT"), times = c(redirect = 0, namelookup = 3.7e-05, 
+    connect = 3.7e-05, pretransfer = 0.000217, starttransfer = 0.264812, 
+    total = 0.264934)), class = "response")
