@@ -1,9 +1,9 @@
 structure(list(url = "https://api.open-meteo.com/v1/forecast?latitude=45.46427&longitude=9.18951&timezone=auto&hourly=lksdfj", 
-    status_code = 400L, headers = structure(list(date = "Tue, 17 Oct 2023 10:18:30 GMT", 
+    status_code = 400L, headers = structure(list(date = "Wed, 25 Oct 2023 11:26:18 GMT", 
         `content-type` = "application/json; charset=utf-8", `content-length` = "125", 
         `content-encoding` = "deflate"), class = c("insensitive", 
     "list")), all_headers = list(list(status = 400L, version = "HTTP/2", 
-        headers = structure(list(date = "Tue, 17 Oct 2023 10:18:30 GMT", 
+        headers = structure(list(date = "Wed, 25 Oct 2023 11:26:18 GMT", 
             `content-type` = "application/json; charset=utf-8", 
             `content-length` = "125", `content-encoding` = "deflate"), class = c("insensitive", 
         "list")))), cookies = structure(list(domain = logical(0), 
@@ -11,7 +11,7 @@ structure(list(url = "https://api.open-meteo.com/v1/forecast?latitude=45.46427&l
         expiration = structure(numeric(0), class = c("POSIXct", 
         "POSIXt")), name = logical(0), value = logical(0)), row.names = integer(0), class = "data.frame"), 
     content = charToRaw("{\"error\":true,\"reason\":\"Cannot initialize SurfaceAndPressureVariable<ForecastSurfaceVariable, ForecastPressureVariable> from invalid String value lksdfj for key \"}"), 
-    date = structure(1697537910, class = c("POSIXct", "POSIXt"
-    ), tzone = "GMT"), times = c(redirect = 0, namelookup = 3.4e-05, 
-    connect = 3.4e-05, pretransfer = 0.000135, starttransfer = 0.280412, 
-    total = 0.280634)), class = "response")
+    date = structure(1698233178, class = c("POSIXct", "POSIXt"
+    ), tzone = "GMT"), times = c(redirect = 0, namelookup = 4.6e-05, 
+    connect = 4.6e-05, pretransfer = 0.000213, starttransfer = 0.269881, 
+    total = 0.269963)), class = "response")
